// Includes
#include "bsp_api.h"
#include "m13_ra6m3_ek_camera.h"
#include "m13_ra6m3_ek_config.h"
#include "OV7670.h"

#if (!BSP_CONFIG_CAMERA_YUV)

// Custom camera resolution configuration
#define H_RES_START_VALUE  ( (OV_7670_MAX_H_PIXEL - OV_7670_CAPTURE_H_RES) / 2 )
#define H_RES_STOP_VALUE   ( H_RES_START_VALUE + OV_7670_CAPTURE_H_RES )
#define H_START_LSB_MASK   (0x07)
#define H_STOP_LSB_MASK    (0x07)

#define V_RES_START_VALUE  ( (OV_7670_MAX_V_PIXEL - OV_7670_CAPTURE_V_RES) / 2)
#define V_RES_STOP_VALUE   ( V_RES_START_VALUE + OV_7670_CAPTURE_V_RES)
#define V_START_LSB_MASK   (0x03)
#define V_STOP_LSB_MASK    (0x03)

#endif

#if (BSP_CONFIG_CAMERA_YUV)
// Configuration for YUV in QVGA (320x240) sensor centered manually
#define H_RES_START_VALUE  (168)
#define H_RES_STOP_VALUE   (488)
#define H_START_LSB_MASK   (0x07)
#define H_STOP_LSB_MASK    (0x07)

#define V_RES_START_VALUE  (124)
#define V_RES_STOP_VALUE   (364)
#define V_START_LSB_MASK   (0x03)
#define V_STOP_LSB_MASK    (0x03)

#endif

// Intermidiate values
#define H_REF_HSTART_LSB   (H_RES_START_VALUE & H_START_LSB_MASK)
#define H_REF_HSTOP_LSB    (H_RES_STOP_VALUE  & H_STOP_LSB_MASK) << 3
#define V_REF_VSTART_LSB   (V_RES_START_VALUE & V_START_LSB_MASK)
#define V_REF_VSTOP_LSB    (V_RES_STOP_VALUE  & V_STOP_LSB_MASK) << 2


// Calculate values for Horizontal resolution Registers
#define HSTART_DEFAULT     ( H_RES_START_VALUE >> 3 )
#define HSTOP_DEFAULT      ( H_RES_STOP_VALUE >> 3 )
#define HREF_DEFAULT       ( H_REF_HSTOP_LSB | H_REF_HSTART_LSB )

// Calculate values for Vertical resolution Registers
#define VSTART_DEFAULT     ( V_RES_START_VALUE >> 2 )
#define VSTOP_DEFAULT      ( V_RES_STOP_VALUE >> 2 )
#define VREF_DEFAULT       ( V_REF_VSTOP_LSB | V_REF_VSTART_LSB )

// OV7670 configuration table
const ov_reg_t OV7670_config[] = {

  /* Color Format configuration */
  { OV7670_COM7   ,  OV7670_COM7_CONFIG },
  { OV7670_RGB444 ,  OV7670_RGB444_DISABLE },
  { OV7670_COM1   ,  0x00 },
  { OV7670_COM15  ,  OV7670_COM15_CONFIG },

  /* Default 10 : U Y V Y */
  { OV7670_TSLB   ,  ( OV7670_TSLB__UV_SWAP_1 | OV7670_TSLB_AUTO_OUT | 0x04 ) },
  { OV7670_COM13  ,  ( OV7670_COM13_UV_SWAP_0 | OV7670_COM13_GAMMA_EN | OV7670_COM13_UV_SAT ) },
  
  /* VSYNC / HSYNC polarization */  
  { OV7670_COM10  ,  ( (!OV7670_COM10_VSYNC_N) | (!OV7670_COM10_HSYNC_N) )  },

  /* Scaling */
  { OV7670_COM3              , 0x00 },
  { OV7670_COM14             , 0x00 },
  { OV7670_SCALING_XSC       , 0x3A },
  { OV7670_SCALING_YSC       , 0x35 },
  { OV7670_SCALING_DCWCTR    , 0x11 },
  { OV7670_SCALING_PCLK_DIV  , 0xF1 },
  { OV7670_SCALING_PCLK_DELAY, 0x02 },


  /* Windowing  */
  { OV7670_HSTART , HSTART_DEFAULT },
  { OV7670_HSTOP  , HSTOP_DEFAULT  },
  { OV7670_HREF   , HREF_DEFAULT | 0x80   },
  { OV7670_VSTART , VSTART_DEFAULT },
  { OV7670_VSTOP  , VSTOP_DEFAULT  },
  { OV7670_VREF   , VREF_DEFAULT   },

  /* Gamma curve */
  { OV7670_SLOP  , 0x20 },
  { OV7670_GAM1  , 0x10 },
  { OV7670_GAM2  , 0x1E },
  { OV7670_GAM3  , 0x35 },
  { OV7670_GAM4  , 0x5A },
  { OV7670_GAM5  , 0x69 },
  { OV7670_GAM6  , 0x76 },
  { OV7670_GAM7  , 0x80 },
  { OV7670_GAM8  , 0x88 },
  { OV7670_GAM9  , 0x8F },
  { OV7670_GAM10 , 0x96 },
  { OV7670_GAM11 , 0xA3 },
  { OV7670_GAM12 , 0xAF },
  { OV7670_GAM13 , 0xC4 },
  { OV7670_GAM14 , 0xD7 },
  { OV7670_GAM15 , 0xE8 },

  /* AGC and AEC parameters.  Note we start by disabling those features, then turn them only after tweaking the values. */
  { OV7670_COM8    , ( (OV7670_COM8_FASTAEC) | (OV7670_COM8_AEC_STEP) | (OV7670_COM8_BAND_FILT) ) },
  { OV7670_GAIN    , 0x00 },
  { OV7670_AECH    , 0x00 },
  { OV7670_COM4    , 0x40 }, /* magic reserved bit */
  { OV7670_COM9    , 0x38 }, /* 4x gain + magic rsvd bit */ //0x18 0x38
  { OV7670_BD50MAX , 0x05 },
  { OV7670_BD60MAX , 0x07 },
  { OV7670_AEW     , 0x95 },
  { OV7670_AEB     , 0x33 },
  { OV7670_VPT     , 0xE3 },
  { OV7670_HAECC1  , 0x78 },
  { OV7670_HAECC2  , 0x68 },
  { OV7670_RSVD_A1 , 0x03 }, /* magic reserved bit */
  { OV7670_HAECC3  , 0xD8 },
  { OV7670_HAECC4  , 0xD8 },
  { OV7670_HAECC5  , 0xF0 },
  { OV7670_HAECC6  , 0x90 },
  { OV7670_HAECC7  , 0x94 },
  { OV7670_COM8    , ( OV7670_COM8_FASTAEC | OV7670_COM8_AEC_STEP | OV7670_COM8_BAND_FILT | OV7670_COM8_AGC_EN | OV7670_COM8_AEC_EN ) },
  
  /* Almost all of these are magic "reserved" values. */
  { OV7670_COM5    , 0x61 },	{ OV7670_COM6    , 0x4B },
  { OV7670_RSVD_16 , 0x02 },	{ OV7670_MVFP    , 0x07 },
  { OV7670_ADCCTR1 , 0x02 },	{ OV7670_ADCCTR2 , 0x91 },
  { OV7670_RSVD_29 , 0x07 },	{ OV7670_CHLF    , 0x0B },
  { OV7670_RSVD_35 , 0x0B },	{ OV7670_ADC     , 0x1D },
  { OV7670_ACOM    , 0x71 },	{ OV7670_OFON    , 0x2A },
  { OV7670_COM12   , 0x78 },	{ OV7670_RSVD_4D , 0x40 },
  { OV7670_RSVD_4E , 0x20 },	{ OV7670_GFIX    , 0x00 },
  { OV7670_DBLV    , 0x4A },	{ OV7670_REG74   , 0x10 },
  { OV7670_RSVD_8D , 0x4F },	{ OV7670_RSVD_8E , 0x00 }, 
  { OV7670_RSVD_8F , 0x00 },	{ OV7670_RSVD_90 , 0x00 },
  { OV7670_RSVD_91 , 0x00 },	{ OV7670_RSVD_96 , 0x00 },
  { OV7670_RSVD_9A , 0x00 },	{ OV7670_RSVD_B0 , 0x84 }, /* important for YUV color to be correct */
  { OV7670_ABLC1   , 0x0C },	{ OV7670_RSVD_B2 , 0x0E },
  { OV7670_THL_ST  , 0x82 },	{ OV7670_RSVD_B8 , 0x0A },
  
/* More reserved magic, some of which tweaks white balance */
  { OV7670_AWBC1   , 0x0A },	{ OV7670_AWBC2   , 0xF0 },
  { OV7670_AWBC3   , 0x34 },	{ OV7670_AWBC4   , 0x58 },
  { OV7670_AWBC5   , 0x28 },	{ OV7670_AWBC6   , 0x3A },
  { OV7670_RSVD_59 , 0x88 },	{ OV7670_RSVD_5A , 0x88 },
  { OV7670_RSVD_5B , 0x44 },	{ OV7670_RSVD_5C , 0x67 },
  { OV7670_RSVD_5D , 0x49 },	{ OV7670_RSVD_5E , 0x0E },
  { OV7670_AWBCTR3 , 0x0A },
  { OV7670_AWBCTR2 , 0x55 },  
  { OV7670_AWBCTR1 , 0x11 },
  { OV7670_AWBCTR0 , 0x9F }, /* "9E for advance AWB" */   //9F
  { OV7670_GGAIN   , 0x40 },	{ OV7670_BLUE    , 0x40 },
  { OV7670_RED     , 0xFF },
  { OV7670_COM8    , ( OV7670_COM8_FASTAEC | OV7670_COM8_AEC_STEP | OV7670_COM8_BAND_FILT | OV7670_COM8_AGC_EN | OV7670_COM8_AEC_EN | OV7670_COM8_AWB_EN ) },

  /* color matrix coefficient */
  { OV7670_MTX1    , OV7670_MTX1_CONFIG }, // 0x80 0xB3
  { OV7670_MTX2    , OV7670_MTX2_CONFIG }, // 0x80 0xB3
  { OV7670_MTX3    , OV7670_MTX3_CONFIG }, // 0x00 0x00
  { OV7670_MTX4    , OV7670_MTX4_CONFIG }, // 0x22 0x3D
  { OV7670_MTX5    , OV7670_MTX5_CONFIG }, // 0x5E 0xA7
  { OV7670_MTX6    , OV7670_MTX6_CONFIG }, // 0x80 0xE4
  { OV7670_MTXS    , 0x9E }, // 0x9E
  { OV7670_COM16   , 0x08 },         
  { OV7670_REG75   , 0x05 },    { OV7670_REG76   , 0xE1 },
  { OV7670_DNSTH   , 0x00 },    { OV7670_REG77   , 0x01 },
  { OV7670_REG4B   , 0x09 },    { OV7670_SATCTR  , 0x60 },		
  { OV7670_COM16   , 0x18 }, // Edge enhancement, de-noise, AWG gain enabled 0x38
  { OV7670_CONTRAS , 0x40 },
 
  { OV7670_ARBLM   , 0x11 },	{ OV7670_COM11   , ( OV7670_COM11_EXPOSURE | OV7670_COM11_D56_AUTO ) },
  { OV7670_NT_CTRL , 0x88 },	{ OV7670_RSVD_96 , 0x00 },
  { OV7670_RSVD_96 , 0x30 },	{ OV7670_RSVD_98 , 0x20 },
  { OV7670_RSVD_99 , 0x30 },	{ OV7670_RSVD_9A , 0x84 },
  { OV7670_RSVD_9B , 0x29 },	{ OV7670_RSVD_9C , 0x03 },
  { OV7670_BD50ST  , 0x4C },	{ OV7670_BD60ST  , 0x3F },
  { OV7670_RSVD_78 , 0x04 }, 
  
  /* Extra-weird stuff.  Some sort of multiplexor register */
  { OV7670_RSVD_79 , 0x01 },	{ OV7670_RSVD_C8 , 0xF0 },
  { OV7670_RSVD_79 , 0x0F },	{ OV7670_RSVD_C8 , 0x00 },
  { OV7670_RSVD_79 , 0x10 },	{ OV7670_RSVD_C8 , 0x7E },
  { OV7670_RSVD_79 , 0x0A },	{ OV7670_RSVD_C8 , 0x80 },
  { OV7670_RSVD_79 , 0x0B },	{ OV7670_RSVD_C8 , 0x01 },
  { OV7670_RSVD_79 , 0x0C },	{ OV7670_RSVD_C8 , 0x0F },
  { OV7670_RSVD_79 , 0x0D },	{ OV7670_RSVD_C8 , 0x20 },
  { OV7670_RSVD_79 , 0x09 },	{ OV7670_RSVD_C8 , 0x80 },
  { OV7670_RSVD_79 , 0x02 },	{ OV7670_RSVD_C8 , 0xC0 },
  { OV7670_RSVD_79 , 0x03 },	{ OV7670_RSVD_C8 , 0x40 },
  { OV7670_RSVD_79 , 0x05 },	{ OV7670_RSVD_C8 , 0x30 },
  { OV7670_RSVD_79 , 0x26 },
  
  /* fps */
  { OV7670_CLKRC, 0x00 },

  /* Others */
  { OV7670_MVFP, ( OV7670_MVFP_MIRROR | OV7670_MVFP_VFLIP ) },
  { 0xFF, 0xFF}, // End marker
};





