/**
 * @file OV7670.h
 * @brief M13DESIGN OV7670 driver
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2022 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/
#include "m13_ra6m3_ek_lcd.h"
#include "m13_ra6m3_ek_config.h"

#ifndef _OV7670_H
#define _OV7670_H

#define OV_7670_MAX_H_PIXEL       (640)
#define OV_7670_MAX_V_PIXEL       (480)

#if (BSP_CONFIG_CAMERA_CUSTOM_RES)

#define OV_7670_CAPTURE_H_RES     (272)
#define OV_7670_CAPTURE_V_RES     (480)

#endif

#if (BSP_CONFIG_CAMERA_QVGA)

#define OV_7670_CAPTURE_H_RES     (240)
#define OV_7670_CAPTURE_V_RES     (320)

#endif

#if (BSP_CONFIG_CAMERA_QQVGA)

#define OV_7670_CAPTURE_H_RES     (120)
#define OV_7670_CAPTURE_V_RES     (160)

#endif

#if ( (OV_7670_CAPTURE_V_RES > LCD_WIDTH) | (OV_7670_CAPTURE_H_RES > LCD_HEIGHT ) )

#error "Please correct the camera capture resolution as it will not fit on the lcd"

#endif

#define OV7670_GAIN               0x00
#define OV7670_BLUE               0x01
#define OV7670_RED                0x02
#define OV7670_VREF               0x03
#define OV7670_COM1               0x04
#define OV7670_BAVE               0x05
#define OV7670_GBAVE              0x06
#define OV7670_AECHH              0x07
#define OV7670_RAVE               0x08
#define OV7670_COM2               0x09
#define OV7670_PID                0x0A
#define OV7670_VER                0x0B
#define OV7670_COM3               0x0C
#define OV7670_COM4               0x0D
#define OV7670_COM5               0x0E
#define OV7670_COM6               0x0F
#define OV7670_AECH               0x10
#define OV7670_CLKRC              0x11
#define OV7670_COM7               0x12
#define OV7670_COM8               0x13
#define OV7670_COM9               0x14
#define OV7670_COM10              0x15
#define OV7670_RSVD_16            0x16
#define OV7670_HSTART             0x17
#define OV7670_HSTOP              0x18
#define OV7670_VSTART             0x19
#define OV7670_VSTOP              0x1A
#define OV7670_PSHFT              0x1B
#define OV7670_MIDH               0x1C
#define OV7670_MIDL               0x1D
#define OV7670_MVFP               0x1E
#define OV7670_LAEC               0x1F
#define OV7670_ADCCTR0            0x20
#define OV7670_ADCCTR1            0x21
#define OV7670_ADCCTR2            0x22
#define OV7670_ADCCTR3            0x23
#define OV7670_AEW                0x24
#define OV7670_AEB                0x25
#define OV7670_VPT                0x26
#define OV7670_BBIAS              0x27
#define OV7670_GGBIAS             0x28
#define OV7670_RSVD_29            0x29
#define OV7670_EXHCH              0x2A
#define OV7670_EXHCL              0x2B
#define OV7670_RBIAS              0x2C
#define OV7670_ADVFL              0x2D
#define OV7670_ADVFH              0x2E
#define OV7670_YAVE               0x2F
#define OV7670_HSYST              0x30
#define OV7670_HSYEN              0x31
#define OV7670_HREF               0x32
#define OV7670_CHLF               0x33
#define OV7670_ARBLM              0x34
#define OV7670_RSVD_35            0x35
#define OV7670_RSVD_36            0x36
#define OV7670_ADC                0x37
#define OV7670_ACOM               0x38
#define OV7670_OFON               0x39
#define OV7670_TSLB               0x3A
#define OV7670_COM11              0x3B
#define OV7670_COM12              0x3C
#define OV7670_COM13              0x3D
#define OV7670_COM14              0x3E
#define OV7670_EDGE               0x3F
#define OV7670_COM15              0x40
#define OV7670_COM16              0x41
#define OV7670_COM17              0x42
#define OV7670_AWBC1              0x43
#define OV7670_AWBC2              0x44
#define OV7670_AWBC3              0x45
#define OV7670_AWBC4              0x46
#define OV7670_AWBC5              0x47
#define OV7670_AWBC6              0x48
#define OV7670_RSVD_49            0x49
#define OV7670_RSVD_4A            0x4A
#define OV7670_REG4B              0x4B
#define OV7670_DNSTH              0x4C
#define OV7670_RSVD_4D            0x4D
#define OV7670_RSVD_4E            0x4E
#define OV7670_MTX1               0x4F
#define OV7670_MTX2               0x50
#define OV7670_MTX3               0x51
#define OV7670_MTX4               0x52
#define OV7670_MTX5               0x53
#define OV7670_MTX6               0x54
#define OV7670_BRIGHT             0x55
#define OV7670_CONTRAS            0x56
#define OV7670_CONTRAS_CEN        0x57
#define OV7670_MTXS               0x58
#define OV7670_RSVD_59            0x59
#define OV7670_RSVD_5A            0x5A
#define OV7670_RSVD_5B            0x5B
#define OV7670_RSVD_5C            0x5C
#define OV7670_RSVD_5D            0x5D
#define OV7670_RSVD_5E            0x5E
#define OV7670_RSVD_5F            0x5F
#define OV7670_RSVD_60            0x60
#define OV7670_RSVD_61            0x61
#define OV7670_LCC1               0x62
#define OV7670_LCC2               0x63
#define OV7670_LCC3               0x64
#define OV7670_LCC4               0x65
#define OV7670_LCC5               0x66
#define OV7670_MANU               0x67
#define OV7670_MANV               0x68
#define OV7670_GFIX               0x69
#define OV7670_GGAIN              0x6A
#define OV7670_DBLV               0x6B
#define OV7670_AWBCTR3            0x6C
#define OV7670_AWBCTR2            0x6D
#define OV7670_AWBCTR1            0x6E
#define OV7670_AWBCTR0            0x6F
#define OV7670_SCALING_XSC        0x70
#define OV7670_SCALING_YSC        0x71
#define OV7670_SCALING_DCWCTR     0x72
#define OV7670_SCALING_PCLK_DIV   0x73
#define OV7670_REG74              0x74
#define OV7670_REG75              0x75
#define OV7670_REG76              0x76
#define OV7670_REG77              0x77
#define OV7670_RSVD_78            0x78
#define OV7670_RSVD_79            0x79
#define OV7670_SLOP               0x7A
#define OV7670_GAM1               0x7B
#define OV7670_GAM2               0x7C
#define OV7670_GAM3               0x7D
#define OV7670_GAM4               0x7E
#define OV7670_GAM5               0x7F
#define OV7670_GAM6               0x80
#define OV7670_GAM7               0x81
#define OV7670_GAM8               0x82
#define OV7670_GAM9               0x83
#define OV7670_GAM10              0x84
#define OV7670_GAM11              0x85
#define OV7670_GAM12              0x86
#define OV7670_GAM13              0x87
#define OV7670_GAM14              0x88
#define OV7670_GAM15              0x89
#define OV7670_RSVD_8A            0x8A
#define OV7670_RSVD_8B            0x8B
#define OV7670_RGB444             0x8C
#define OV7670_RSVD_8D            0x8D
#define OV7670_RSVD_8E            0x8E
#define OV7670_RSVD_8F            0x8F
#define OV7670_RSVD_90            0x90
#define OV7670_RSVD_91            0x91
#define OV7670_DM_LNL             0x92
#define OV7670_DM_LNH             0x93
#define OV7670_LCC6               0x94
#define OV7670_LCC7               0x95
#define OV7670_RSVD_96            0x96
#define OV7670_RSVD_97            0x97
#define OV7670_RSVD_98            0x98
#define OV7670_RSVD_99            0x99
#define OV7670_RSVD_9A            0x9A
#define OV7670_RSVD_9B            0x9B
#define OV7670_RSVD_9C            0x9C
#define OV7670_BD50ST             0x9D
#define OV7670_BD60ST             0x9E
#define OV7670_HAECC1             0x9F
#define OV7670_HAECC2             0xA0
#define OV7670_RSVD_A1            0xA1
#define OV7670_SCALING_PCLK_DELAY 0xA2
#define OV7670_RSVD_A3            0xA3
#define OV7670_NT_CTRL            0xA4
#define OV7670_BD50MAX            0xA5
#define OV7670_HAECC3             0xA6
#define OV7670_HAECC4             0xA7
#define OV7670_HAECC5             0xA8
#define OV7670_HAECC6             0xA9
#define OV7670_HAECC7             0xAA
#define OV7670_BD60MAX            0xAB
#define OV7670_STR_OPT            0xAC
#define OV7670_STR_R              0xAD
#define OV7670_STR_G              0xAE
#define OV7670_STR_B              0xAF
#define OV7670_RSVD_B0            0xB0
#define OV7670_ABLC1              0xB1
#define OV7670_RSVD_B2            0xB2
#define OV7670_THL_ST             0xB3
#define OV7670_RSVD_B4            0xB4
#define OV7670_THL_DLT            0xB5
#define OV7670_RSVD_B6            0xB6
#define OV7670_RSVD_B7            0xB7
#define OV7670_RSVD_B8            0xB8
#define OV7670_RSVD_B9            0xB9
#define OV7670_RSVD_BA            0xBA
#define OV7670_RSVD_BB            0xBB
#define OV7670_RSVD_BC            0xBC
#define OV7670_RSVD_BD            0xBD
#define OV7670_AD_CHB             0xBE
#define OV7670_AD_CHR             0xBF
#define OV7670_AD_CHGB            0xC0
#define OV7670_AD_CHBR            0xC1
#define OV7670_RSVD_C2            0xC2
#define OV7670_RSVD_C3            0xC3
#define OV7670_RSVD_C4            0xC4
#define OV7670_RSVD_C5            0xC5
#define OV7670_RSVD_C6            0xC6
#define OV7670_RSVD_C7            0xC7
#define OV7670_RSVD_C8            0xC8
#define OV7670_SATCTR             0xC9


// Common Control 3 Register
#define OV7670_COM3_DCW           0x04
#define OV7670_COM3_SCALE         0x08
#define OV7670_COM3_MSB_LSB_SWAP  0x40

// Common Control 7 Register
#define OV7670_COM7_RGB           0x04
#define OV7670_COM7_YUV           0x00
#define OV7670_COM7_QVGA          0x10
#define OV7670_COM7_BAYER         0x01
#define OV7670_COM7_PBAYER        0x05

// Common Control 8 Register
#define OV7670_COM8_FASTAEC       0x80
#define OV7670_COM8_AEC_STEP      0x40
#define OV7670_COM8_BAND_FILT     0x20
#define OV7670_COM8_AGC_EN        0x04
#define OV7670_COM8_AWB_EN        0x02
#define OV7670_COM8_AEC_EN        0x01

// Common Control 10 Register
#define OV7670_COM10_VSYNC_N      0x02
#define OV7670_COM10_HSYNC_N      0x01

// Mirro/VFlip Enable Register
#define OV7670_MVFP_MIRROR        0x20
#define OV7670_MVFP_VFLIP         0x10
#define OV7670_MVFP_BLACK_SUN_EN  0x04

// Line Buffer Test Option Register
#define OV7670_TSLB_NEG_IMAGE     0x20
#define OV7670_TSLB_UV_FIXED_OUT  0x10
#define OV7670_TSLB__UV_SWAP_1    0x08
#define OV7670_TSLB_AUTO_OUT      0x01

// Common Control 11 Register
#define OV7670_COM11_NIGHTMODE    0x80
#define OV7670_COM11_FRAME_NORM   0x00
#define OV7670_COM11_FRAME_HALF   0x20
#define OV7670_COM11_FRAME_QUAR   0x40
#define OV7670_COM11_FRAME_8TH    0x60
#define OV7670_COM11_D56_AUTO     0x10
#define OV7670_COM11_BW_SELECT    0x08
#define OV7670_COM11_EXPOSURE     0x02

// Common Control 13 Register
#define OV7670_COM13_GAMMA_EN     0x80
#define OV7670_COM13_UV_SAT       0x40
#define OV7670_COM13_UV_SWAP_0    0x01

// Common Control 14 Register
#define OV7670_COM14_DCW_EN       0x10
#define OV7670_COM14_MANUAL       0x08

// Common Control 15 Register
#define OV7670_COM15_RGB565       0x10
#define OV7670_COM15_RGB555	      0x30
#define OV7670_COM15_00_FF        0xC0

// RGB444 Configuration Register
#define OV7670_RGB444_DISABLE     0x00

#endif
