/**
 * @file m13_ra6m3_ek_config.h
 * @brief M13-RA6M3-EK Configuration
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_CONFIG_H
#define _M13_RA6M3_EK_CONFIG_H


/**    Macro definitions    **/

#define BSP_CONFIG_I2C_NO_RESTART_CONDITION        (1)   // Remove Restart condition from I2C Read routine

#define BSP_CONFIG_ENABLE_TRACE_DEBUG              (0)   // Choose debug message level to output on uart console

#define BSP_CONFIG_ENABLE_TRACE_TEST               (1)   // Trace PRINTF_TEST macros only

#define BSP_CONFIG_ENABLE_SDRAM_TEST               (0)   // Enable/Disable SDRAM Test

#define BSP_CONFIG_ENABLE_HEAP_IN_SDRAM            (0)   // Make sure to Enable "configAPPLICATION_ALLOCATED_HEAP" through the Configuration.xml interface before enabling BSP_HEAP_SDRAM

/**   Display configuration    **/
#define BSP_CONFIG_ENABLE_LCD_BUFFER_IN_SDRAM      (1)   // Relocate the LCD buffers in SDRAM

#define BSP_CONFIG_ENABLE_LCD_DOUBLE_BUFFER        (1)   // Enable/Disable double frame buffer for the LCD

#define BSP_CONFIG_ENABLE_LCD_GRAPHIC_LAYER2       (0)   // Enable/Disable the second graphic layer for the LCD

/**   QSPI configuration    **/
#define BSP_CONFIG_ENABLE_QPI_MODE                 (1)   // Enable/Disable QPI Mode for QSPI device

/**   Camera configuration    **/
#define BSP_CONFIG_ENABLE_CAMERA_BUFFER_IN_SDRAM   (0)   // Relocate the Camera buffers in SDRAM (Not Applicable, leave it 0)

#define BSP_CONFIG_CAMERA_IS_OV7740                (0)   // Camera used is OV7740

#define BSP_CONFIG_CAMERA_IS_OV7670                (1)   // Camera used is OV7670

#define BSP_CONFIG_CAMERA_YUV                      (0)   // Choose camera output colour type : 1 = YUV / 0 = RGB (RGB Not Applicable for OV7740)

#define BSP_CONFIG_CAMERA_CUSTOM_RES               (1)   // Custom camera resolution

#define BSP_CONFIG_CAMERA_QVGA                     (0)   // QVGA resolution (320x240)

#define BSP_CONFIG_CAMERA_QQVGA                    (0)   // QQVGA resolution (160x120)

#define BSP_CONFIG_CAMERA_I2C_TEST                 (0)   // Enable i2c test for camera during init routine



#if ( BSP_CONFIG_ENABLE_LCD_DOUBLE_BUFFER )
#define BSP_LCD_MAX_FRAME_BUFFER                   (2)
#else
#define BSP_LCD_MAX_FRAME_BUFFER                   (1)
#endif

#if ( BSP_CONFIG_ENABLE_LCD_BUFFER_IN_SDRAM )
#define BSP_LCD_RAM_SECTION                        ".sdram"
#else
#define BSP_LCD_RAM_SECTION                        ".bss"
#endif

#if ( BSP_CONFIG_ENABLE_CAMERA_BUFFER_IN_SDRAM )
#define BSP_CAMERA_RAM_SECTION                     ".sdram"
#else
#define BSP_CAMERA_RAM_SECTION                     ".bss"
#endif

#if ( !BSP_CONFIG_CAMERA_YUV )
#define BSP_CONFIG_CAMERA_RGB                      (1)
#endif

#if ( BSP_CONFIG_CAMERA_IS_OV7740 & BSP_CONFIG_CAMERA_IS_OV7670 )
#error "Please choose only one camera configuration"

#endif

#if ( BSP_CONFIG_CAMERA_IS_OV7740 & BSP_CONFIG_CAMERA_RGB )
#error "Please review your camera configuration, OV7740 does not work in RGB mode"

#endif

#if ( ( BSP_CONFIG_CAMERA_CUSTOM_RES & ( BSP_CONFIG_CAMERA_QVGA | BSP_CONFIG_CAMERA_QQVGA ) ) | ( BSP_CONFIG_CAMERA_QQVGA & ( BSP_CONFIG_CAMERA_QVGA | BSP_CONFIG_CAMERA_CUSTOM_RES ) )  )
#error "Please review your camera resolution configuration. Cannot select multiple resolution at the same time"

#endif

#endif
