/**
 * @file m13_ra6m3_ek_i2c.h
 * @brief M13-RA6M3-EK I2C BSP
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_I2C_H
#define _M13_RA6M3_EK_I2C_H

// Includes
#include "bsp_api.h"
#include "r_iic_master.h"
#include "r_sci_i2c.h"
#include "m13_ra6m3_ek_status.h"

// Macro definitions

// typedef definitions
typedef enum
{
    BSP_I2C_CHANNEL_0 = 0,
    BSP_I2C_CHANNEL_6 = 6,
} bsp_i2c_channel_t;

typedef enum
{
    BSP_I2C_SLAVE_ADDR_NONE     = 0x00,
    BSP_I2C_SLAVE_ADDR_AUDIO    = 0x18,
    BSP_I2C_SLAVE_ADDR_ACC      = 0x19,
    BSP_I2C_SLAVE_ADDR_CAMERA   = 0x21, // OV7740 address
	BSP_I2C_SLAVE_ADDR_TOUCH    = 0x38,
    BSP_I2C_SLAVE_ADDR_EEPROM   = 0x50,	
} bsp_i2c_slave_addr_t;


typedef enum
{
    BSP_I2C_SLAVE_ADDR_CLICK14 = 0x3F,
    BSP_I2C_SLAVE_ADDR_HYGRO   = 0x40,
} bsp_sci6_slave_addr_t;

typedef void *bsp_i2c_handle_t;

// BSP Functions
bsp_status_t bsp_i2c_init(bsp_i2c_channel_t channel);

bsp_i2c_handle_t bsp_i2c_open(bsp_i2c_channel_t channel);

bsp_status_t bsp_i2c_write(bsp_i2c_handle_t handle, uint8_t device_address, uint32_t sub_address,
    uint32_t sub_address_length, const uint8_t *data, size_t data_length);

bsp_status_t bsp_i2c_read(bsp_i2c_handle_t handle, uint8_t device_address, uint32_t sub_address,
    uint32_t sub_address_length, uint8_t *data, size_t data_length);

#endif
