/**
 * @file m13_ra6m3_ek_lcd.h
 * @brief m13_ra6m3_ek LCD BSP
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http:// www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_LCD_H
#define _M13_RA6M3_EK_LCD_H

// Includes
#include "r_glcdc.h"
#include "r_display_api.h"
#include "m13_ra6m3_ek_config.h"
#include "m13_ra6m3_ek_pinout.h"
#include "m13_ra6m3_ek_status.h"
#include "m13_logo_table.h"
#include "fonts.h"

// Type definitions


// User setting
#ifndef BSP_LCD_MAX_FRAME_BUFFER
#define BSP_LCD_MAX_FRAME_BUFFER        1
#endif

#ifndef BSP_LCD_RAM_SECTION
#define BSP_LCD_RAM_SECTION             ".bss"
#endif

// LCD display dimensions
#define LCD_WIDTH                       480
#define LCD_HEIGHT                      272

//typedef enum
//{
//    LCD_WIDTH  = 480,
//    LCD_HEIGHT = 272,
//}bsp_lcd_size;

#define DISPLAY_FRAME_LAYER(n) (1 - (n))

// Frame buffer configuration
#define DISPLAY_BITS_PER_PIXEL_INPUT0 (16)
#define DISPLAY_BUFFER_STRIDE_BYTES_INPUT0  (((LCD_WIDTH * DISPLAY_BITS_PER_PIXEL_INPUT0 + 0x1FF) >> 9) << 6)
#define DISPLAY_BUFFER_STRIDE_PIXELS_INPUT0  ((DISPLAY_BUFFER_STRIDE_BYTES_INPUT0 * 8) / DISPLAY_BITS_PER_PIXEL_INPUT0)

typedef enum
{
	ROTATION_ZERO = 0,
	ROTATION_090 = 90,
	ROTATION_180 = 180,
	ROTATION_270 = 270,
}bsp_rotation;

// LCD Color codes
#if (DISPLAY_BITS_PER_PIXEL_INPUT0 == 16)

#define LCD_COLOR_BLUE                  0x001F
#define LCD_COLOR_GREEN                 0x07E0
#define LCD_COLOR_RED                   0xF800
#define LCD_COLOR_CYAN                  0x07FF
#define LCD_COLOR_MAGENTA               0xF81F
#define LCD_COLOR_YELLOW                0xFFE0

#define LCD_COLOR_BLACK                 0x0000
#define LCD_COLOR_WHITE                 0xFFFF
#define LCD_COLOR_M13_GREEN1            0x6509
#define LCD_COLOR_M13_GREEN2            0xBEAA
#endif

#define LCD_DEFAULT_BACKGROUND_COLOR    LCD_COLOR_BLUE
#define LCD_DEFAULT_TEXT_COLOR          LCD_COLOR_BLACK

// Back light pin definition
#define LCD_BACKLIGHT_PIN               BSP_IO_PORT_00_PIN_15
#define LCD_BACKLIGHT_OFF               BSP_IO_LEVEL_LOW
#define LCD_BACKLIGHT_ON                BSP_IO_LEVEL_HIGH

typedef uint16_t bsp_color_t;


// LCD BSP functions
void bsp_lcd_io_init (void);
void bsp_lcd_init (void);

void vsync_callback (display_callback_args_t * p_args);
void vsync_wait (void);

void bsp_lcd_enable_double_buffer(void);
void bsp_lcd_swap_buffer(void);
void bsp_lcd_set_display_buffer(uint8_t index);
void bsp_lcd_set_working_buffer(uint8_t index);

// TODO
bsp_status_t bsp_lcd_layer_fade(display_runtime_cfg_t* disp_rt_cfg, uint8_t direction, uint16_t speed);


void bsp_lcd_display_on           (void);
void bsp_lcd_display_off          (void);
void bsp_lcd_clear                (bsp_color_t color);
void bsp_lcd_set_backlight        (bsp_io_level_t backlight);

bsp_color_t bsp_lcd_read_pixel    (uint32_t x, uint32_t y);
void bsp_lcd_draw_pixel           (uint32_t x, uint32_t y, bsp_color_t color);
void bsp_lcd_draw_horizontal_line (uint32_t x, uint32_t y, uint32_t length, bsp_color_t color);
void bsp_lcd_draw_vertical_line   (uint32_t x, uint32_t y, uint32_t length, bsp_color_t color);
void bsp_lcd_draw_rect            (uint32_t x, uint32_t y, uint32_t width, uint32_t height, bsp_color_t color);
void bsp_lcd_fill_rect            (uint32_t x, uint32_t y, uint32_t width, uint32_t height, bsp_color_t color);

void bsp_lcd_set_background_color (bsp_color_t color);
void bsp_lcd_set_text_color       (bsp_color_t color);
void bsp_lcd_set_font             (font_t* p_font);
void bsp_lcd_display_char         (uint32_t x, uint32_t y, uint8_t c);
void bsp_lcd_display_string       (uint32_t x, uint32_t y, const char* string);
void bsp_lcd_draw_image           (uint32_t x, uint32_t y, display_image_t* image, uint32_t rotation);
void bsp_lcd_draw_image_from_cam  (uint32_t x, uint32_t y, void* image, uint32_t rotation);

#endif




