/**
 * @file m13_ra6m3_ek_status.h
 * @brief Error codes description
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_STATUS_H
#define _M13_RA6M3_EK_STATUS_H

// Macro definitions

// Invalid handle value
#define BSP_I2C_INVALID_HANDLE    NULL

/**
 * @brief Error codes
 **/

typedef enum
{
    BSP_STATUS_OK = 0,                  // Success
    BSP_STATUS_FAILURE = 1,             // Generic error code
    BSP_STATUS_INVALID_VERSION,         // Wrong version/ID error code
	BSP_STATUS_TIME_OUT,                // Time out failure
	BSP_STATUS_PIN_CONFIG_FAILURE,		// Pins configuration failure
	BSP_STATUS_OPEN_FAILURE,            // Open failure
    BSP_STATUS_INVALID_CHANNEL,         // Wrong channel error code
    BSP_STATUS_INVALID_PARAMETER,       // Wrong parameter
    BSP_STATUS_INIT_FAILURE,            // Initialization failure
    BSP_STATUS_I2C_READ_FAILURE,        // I2C Read operation failure
    BSP_STATUS_I2C_WRITE_FAILURE,       // I2C Read operation failure
    BSP_STATUS_ADC_READ_FAILURE,        // ADC Read operation failure
    BSP_STATUS_ADC_START_FAILURE,       // ADC scan start operation failure
    BSP_STATUS_ADC_STOP_FAILURE,        // ADC scan stop operation failure
    BSP_STATUS_EEPROM_FAILURE,          // EEPROM generic operation failure
    BSP_STATUS_QSPI_FAILURE,            // QSPI generic operation failure
	BSP_STATUS_QSPI_ID_READ_FAILURE,    // QSPI ID Read operation failure
	BSP_STATUS_QSPI_WRITE_FAILURE,      // QSPI write operation failure
	BSP_STATUS_QSPI_ERASE_FAILURE,      // QSPI erase operation failure
} bsp_status_t;

#endif
