/**
 * @file m13_ra6m3_ek_vcom.h
 * @brief M13-RA6M3-EK Virtual COM definition
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_VCOM_H
#define _M13_RA6M3_EK_VCOM_H

// Includes
#include <stdarg.h>
#include <stdio.h>
#include "FreeRTOS.h"
#include "task.h"
#include "m13_ra6m3_ek_pinout.h"
#include "m13_ra6m3_ek_status.h"
#include "m13_ra6m3_ek_config.h"

typedef char char_t;
typedef signed int int_t;
typedef unsigned int uint_t;

// Macro definitions

// Trace level definitions
#define TRACE_LEVEL_OFF      0
#define TRACE_LEVEL_INFO     1
#define TRACE_LEVEL_DEBUG    2
#define TRACE_LEVEL_ALL      3

// Default trace level
#if (BSP_CONFIG_ENABLE_TRACE_DEBUG == 1)

#ifndef TRACE_LEVEL
   #define TRACE_LEVEL TRACE_LEVEL_DEBUG
#endif

#else

#if (BSP_CONFIG_ENABLE_TRACE_DEBUG == 2)

#ifndef TRACE_LEVEL
   #define TRACE_LEVEL TRACE_LEVEL_DEBUG
#endif

#endif

#ifndef TRACE_LEVEL
   #define TRACE_LEVEL TRACE_LEVEL_INFO
#endif

#endif


#define _PRINTF(...)                      vTaskSuspendAll(), m13_printf_custom(stderr, __VA_ARGS__), xTaskResumeAll()
#define _PRINTF_ARRAY(p, a, n)            vTaskSuspendAll(), m13_display_Array(stderr, p, a, n), xTaskResumeAll()

#if (TRACE_LEVEL >= TRACE_LEVEL_INFO)
#define PRINTF_INFO(...)                  _PRINTF(__VA_ARGS__)
#define PRINTF_ARRAY(p, a, n)             _PRINTF_ARRAY(p, a, n)

#else
   #define PRINTF_INFO(...)
   #define PRINTF_ARRAY(p, a, n)
#endif

#if (TRACE_LEVEL >= TRACE_LEVEL_DEBUG)
   #define PRINTF_DEBUG(...)              _PRINTF(__VA_ARGS__)
   #define PRINTF_ARRAY_DEBUG(p, a, n)    _PRINTF_ARRAY(p, a, n)
#else
   #define PRINTF_DEBUG(...)
   #define PRINTF_ARRAY_DEBUG(p, a, n)
#endif

#if (TRACE_LEVEL >= TRACE_LEVEL_ALL)
   #define PRINTF_ALL(...)                _PRINTF(__VA_ARGS__)
   #define PRINTF_ARRAY_ALL(p, a, n)      _PRINTF_ARRAY(p, a, n)
#else
   #define PRINTF_ALL(...)
   #define PRINTF_ARRAY_ALL(p, a, n)
#endif

#if (BSP_CONFIG_ENABLE_TRACE_TEST == 1)
#define PRINTF_TEST(...)                  _PRINTF(__VA_ARGS__)
#define PRINTF_ARRAY(p, a, n)             _PRINTF_ARRAY(p, a, n)

#else
   #define PRINTF_TEST(...)
   #define PRINTF_ARRAY_ALL(p, a, n)

#endif


// typedef definitions
typedef enum
{
    BSP_VCOM_CHANNEL_0 = 0,
    BSP_VCOM_CHANNEL_1,
    BSP_VCOM_CHANNEL_2,
    BSP_VCOM_CHANNEL_3,
    BSP_VCOM_CHANNEL_4,
    BSP_VCOM_CHANNEL_5,
    BSP_VCOM_CHANNEL_6,
    BSP_VCOM_CHANNEL_7,
    BSP_VCOM_CHANNEL_8,
    BSP_VCOM_CHANNEL_9,
} bsp_vcom_channel_t;


// BSP Functions
void bsp_vcom_init(void);
bsp_status_t bsp_vcom_open(bsp_vcom_channel_t channel);


// M13 printf Specific Functions
void         m13_manual_debug_Init (uint32_t baudrate);
int_t        m13_put_char          (int_t c, FILE *stream);
int          m13_printf_custom     (void *stream, const char *format, ...);
void         m13_display_Array     (FILE *stream, const char_t *prepend, const void *data, size_t length);
int          vfprintf_custom       (void *out, const char *format, va_list args);

#endif

