// Includes
#include "main_thread.h"
#include "bsp_api.h"
#include "cachel1_armv7.h"
#include "m13_ra6m3_ek_led.h"
#include "m13_ra6m3_ek_vcom.h"
#include "m13_ra6m3_ek_config.h"
#include "m13_ra6m3_ek_sdram.h"
#include "m13_ra6m3_ek_camera.h"

// Global variables
SemaphoreHandle_t i2c_channel_0_semaphore;
SemaphoreHandle_t camera_capture_semaphore;

// Functions
extern void lcd_task(void *parameters);
extern void switch_task(void *parameters);
void board_init(void);


/* Main Thread entry function */
/* pvParameters contains TaskHandle_t */
void main_thread_entry(void *pvParameters)
{
    FSP_PARAMETER_NOT_USED (pvParameters);

    portBASE_TYPE status;
    TaskHandle_t task;

    // Initialize board pins and peripherals
    board_init();

    // Create Switch task
     status = xTaskCreate(switch_task, "Switch Task", 500, NULL, 1, &task);

     if( status != pdPASS )
     {
         PRINTF_INFO("Could not create Accelerometer Task \r\n");
     }

     // Create LCD task
     status = xTaskCreate(lcd_task, "LCD Task", 1000, NULL, 1, &task);

     if( status != pdPASS )
     {
         PRINTF_INFO("Could not create LCD Task \r\n");
     }

    // Use main_thread_entry to blink the board leds
    while (1)
    {
        //Turn on LED1 for 50ms)
        bsp_led_on(BSP_LED1);
        vTaskDelay(50);

        //Turn off LED1 for 950ms)
        bsp_led_off(BSP_LED1);
        vTaskDelay(950);
    }
}


void board_init(void)
{

    // Enable cache
    SCB_EnableICache();
    SCB_EnableDCache();

    // Create Mutex for I2C channel 0 access
    i2c_channel_0_semaphore = xSemaphoreCreateMutex();

    // Create Mutex for camera capture
    camera_capture_semaphore = xSemaphoreCreateMutex();

    // Initialize UART for debug
    bsp_vcom_init();

    // Open SCI channel 4 for debug
    bsp_vcom_open(BSP_VCOM_CHANNEL_4);

    // Configure the led pins
    bsp_led_io_init();

    // Configure i2c0 pins
    bsp_i2c_init(BSP_I2C_CHANNEL_0);

    //Init Camera OV7740
    bsp_camera_init();

    // Init SDRAM here if heap is not in SDRAM
#if (BSP_CONFIG_ENABLE_LCD_BUFFER_IN_SDRAM == 1 && BSP_CONFIG_ENABLE_HEAP_IN_SDRAM == 0 )
    bsp_sdram_init();
#endif

    // Start-up message
    PRINTF_INFO("\r\n");
    PRINTF_INFO(" **************************************** \r\n");
    PRINTF_INFO(" ************ M13design Demo ************ \r\n");
    PRINTF_INFO(" **************************************** \r\n");
    PRINTF_INFO("Copyright: 2010-2021 M13design SARL\r\n");
    PRINTF_INFO("Compiled: %s %s\r\n", __DATE__, __TIME__);
    PRINTF_INFO("Target: RA6M3\r\n");
    PRINTF_INFO("Camera LCD Streaming Demo\r\n");
    PRINTF_INFO("\r\n");

#if (BSP_CONFIG_ENABLE_SDRAM_TEST == 1)

    // Initialize sdram pins
    bsp_sdram_init();

    // Launch sdram test routine
    sdram_test();

#endif
}
