// Includes
#include "m13_ra6m3_ek_lcd.h"
#include "m13_ra6m3_ek_vcom.h"
#include "m13_ra6m3_ek_camera.h"

#define BL_ON    (1u)
#define BL_OFF   (0u)

// External and global variables
extern uint16_t screen_rotation;
extern uint16_t *lcd_current_working_buffer;
extern uint8_t bsp_camera_buffer [ BSP_CAM_RESOLUTION ];

// Functions
void lcd_task(void *parameters);

// Private Functions
static void lcd_task_init(void);
static uint32_t lcd_display_test_screen(void);

// LCD Thread entry function
void lcd_task(void *parameters)
{
    FSP_PARAMETER_NOT_USED (parameters);

    // Initialize the lcd
    lcd_task_init();

    while(1)
    {
        lcd_display_test_screen();

        if (BSP_LCD_MAX_FRAME_BUFFER > 1)
        {
            bsp_lcd_swap_buffer();
        }

        vsync_wait();

        vTaskDelay (1);
    }
}

static uint32_t lcd_display_test_screen(void)
{
	uint32_t t1, t2, t3;
	uint32_t x_cam_start, y_cam_start;

#if (OV_7670_CAPTURE_H_RES == OV_7670_CAPTURE_V_RES)
	x_cam_start = ( LCD_WIDTH - BSP_CAM_WIDTH) / 2;
	y_cam_start = ( ( (LCD_HEIGHT - BSP_CAM_HEIGHT) / 2 ) + BSP_CAM_HEIGHT) - 1;
#endif

#if (OV_7670_CAPTURE_H_RES < OV_7670_CAPTURE_V_RES)
    x_cam_start = ( LCD_WIDTH - BSP_CAM_HEIGHT ) / 2;
    y_cam_start = ( ( (LCD_HEIGHT - BSP_CAM_WIDTH) / 2 ) + BSP_CAM_WIDTH) - 1;
#endif

#if (OV_7670_CAPTURE_H_RES > OV_7670_CAPTURE_V_RES)
    x_cam_start = ( LCD_WIDTH - BSP_CAM_HEIGHT ) / 2;
    y_cam_start = ( ( (LCD_HEIGHT - BSP_CAM_WIDTH) / 2 ) + BSP_CAM_WIDTH) ;
#endif


    t1 = xTaskGetTickCount();

    // Take a picture from the camera
    bsp_camera_capture_image();

#if BSP_CONFIG_CAMERA_YUV
    // Convert camera image to rgb and send it to the screen buffer
    bsp_camera_convert_display(bsp_camera_buffer, lcd_current_working_buffer, BSP_CAM_WIDTH, BSP_CAM_HEIGHT);
#endif

#if BSP_CONFIG_CAMERA_RGB
    // Display captured image on the LCD screen
    bsp_lcd_draw_image_from_cam (x_cam_start, y_cam_start, &bsp_camera_buffer[0], ROTATION_090);
#endif

    t2 = xTaskGetTickCount();

    // Calculate the time needed to display a frame from the camera and convert it as Frame Per Second
    t3 = 1000 / ( t2-t1 );

    // Send the calculated frame rate to the VCOM
    PRINTF_TEST(" %u fps \r\n", t3 );

    return t3;
}

static void lcd_task_init(void)
{
    // Configure lcd pins
    bsp_lcd_io_init();

    // Turn on backlight
    bsp_lcd_set_backlight(BL_ON);

    // Initialize lcd controller
    bsp_lcd_init();

    // Start lcd display
    bsp_lcd_display_on();

    // Enable double buffer
    bsp_lcd_enable_double_buffer();

    // clear lcd buffers and display M13 Logo
    bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);

#if (!BSP_CONFIG_CAMERA_CUSTOM_RES)

    bsp_lcd_draw_image (470, 34, &m13_logo_image_204x62, ROTATION_270);

#endif

    bsp_lcd_swap_buffer();

    bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);

#if (!BSP_CONFIG_CAMERA_CUSTOM_RES)

    bsp_lcd_draw_image (470, 34, &m13_logo_image_204x62, ROTATION_270);

#endif

    // Set background color to default color
    bsp_lcd_set_background_color(LCD_DEFAULT_BACKGROUND_COLOR);

    // Set text color to default color
    bsp_lcd_set_text_color(LCD_DEFAULT_TEXT_COLOR);

    // Set font
    bsp_lcd_set_font(&font_14x19);

    // Set screen rotation to default
    screen_rotation = ROTATION_ZERO;
}
